from Qtica import AbstractIcon
from .resource import FeatherIconsResource


class FeatherIcons(AbstractIcon):
    activity: str = ":/feather/icons/activity.svg"
    airplay: str = ":/feather/icons/airplay.svg"
    alert_circle: str = ":/feather/icons/alert-circle.svg"
    alert_octagon: str = ":/feather/icons/alert-octagon.svg"
    alert_triangle: str = ":/feather/icons/alert-triangle.svg"
    align_center: str = ":/feather/icons/align-center.svg"
    align_justify: str = ":/feather/icons/align-justify.svg"
    align_left: str = ":/feather/icons/align-left.svg"
    align_right: str = ":/feather/icons/align-right.svg"
    anchor: str = ":/feather/icons/anchor.svg"
    aperture: str = ":/feather/icons/aperture.svg"
    archive: str = ":/feather/icons/archive.svg"
    arrow_down: str = ":/feather/icons/arrow-down.svg"
    arrow_down_circle: str = ":/feather/icons/arrow-down-circle.svg"
    arrow_down_left: str = ":/feather/icons/arrow-down-left.svg"
    arrow_down_right: str = ":/feather/icons/arrow-down-right.svg"
    arrow_left: str = ":/feather/icons/arrow-left.svg"
    arrow_left_circle: str = ":/feather/icons/arrow-left-circle.svg"
    arrow_right: str = ":/feather/icons/arrow-right.svg"
    arrow_right_circle: str = ":/feather/icons/arrow-right-circle.svg"
    arrow_up: str = ":/feather/icons/arrow-up.svg"
    arrow_up_circle: str = ":/feather/icons/arrow-up-circle.svg"
    arrow_up_left: str = ":/feather/icons/arrow-up-left.svg"
    arrow_up_right: str = ":/feather/icons/arrow-up-right.svg"
    at_sign: str = ":/feather/icons/at-sign.svg"
    award: str = ":/feather/icons/award.svg"
    bar_chart: str = ":/feather/icons/bar-chart.svg"
    bar_chart_2: str = ":/feather/icons/bar-chart-2.svg"
    battery: str = ":/feather/icons/battery.svg"
    battery_charging: str = ":/feather/icons/battery-charging.svg"
    bell: str = ":/feather/icons/bell.svg"
    bell_off: str = ":/feather/icons/bell-off.svg"
    bluetooth: str = ":/feather/icons/bluetooth.svg"
    bold: str = ":/feather/icons/bold.svg"
    book: str = ":/feather/icons/book.svg"
    book_open: str = ":/feather/icons/book-open.svg"
    bookmark: str = ":/feather/icons/bookmark.svg"
    box: str = ":/feather/icons/box.svg"
    briefcase: str = ":/feather/icons/briefcase.svg"
    calendar: str = ":/feather/icons/calendar.svg"
    camera: str = ":/feather/icons/camera.svg"
    camera_off: str = ":/feather/icons/camera-off.svg"
    cast: str = ":/feather/icons/cast.svg"
    check: str = ":/feather/icons/check.svg"
    check_circle: str = ":/feather/icons/check-circle.svg"
    check_square: str = ":/feather/icons/check-square.svg"
    chevron_down: str = ":/feather/icons/chevron-down.svg"
    chevron_left: str = ":/feather/icons/chevron-left.svg"
    chevron_right: str = ":/feather/icons/chevron-right.svg"
    chevron_up: str = ":/feather/icons/chevron-up.svg"
    chevrons_down: str = ":/feather/icons/chevrons-down.svg"
    chevrons_left: str = ":/feather/icons/chevrons-left.svg"
    chevrons_right: str = ":/feather/icons/chevrons-right.svg"
    chevrons_up: str = ":/feather/icons/chevrons-up.svg"
    chrome: str = ":/feather/icons/chrome.svg"
    circle: str = ":/feather/icons/circle.svg"
    clipboard: str = ":/feather/icons/clipboard.svg"
    clock: str = ":/feather/icons/clock.svg"
    cloud: str = ":/feather/icons/cloud.svg"
    cloud_drizzle: str = ":/feather/icons/cloud-drizzle.svg"
    cloud_lightning: str = ":/feather/icons/cloud-lightning.svg"
    cloud_off: str = ":/feather/icons/cloud-off.svg"
    cloud_rain: str = ":/feather/icons/cloud-rain.svg"
    cloud_snow: str = ":/feather/icons/cloud-snow.svg"
    code: str = ":/feather/icons/code.svg"
    codepen: str = ":/feather/icons/codepen.svg"
    codesandbox: str = ":/feather/icons/codesandbox.svg"
    coffee: str = ":/feather/icons/coffee.svg"
    columns: str = ":/feather/icons/columns.svg"
    command: str = ":/feather/icons/command.svg"
    compass: str = ":/feather/icons/compass.svg"
    copy: str = ":/feather/icons/copy.svg"
    corner_down_left: str = ":/feather/icons/corner-down-left.svg"
    corner_down_right: str = ":/feather/icons/corner-down-right.svg"
    corner_left_down: str = ":/feather/icons/corner-left-down.svg"
    corner_left_up: str = ":/feather/icons/corner-left-up.svg"
    corner_right_down: str = ":/feather/icons/corner-right-down.svg"
    corner_right_up: str = ":/feather/icons/corner-right-up.svg"
    corner_up_left: str = ":/feather/icons/corner-up-left.svg"
    corner_up_right: str = ":/feather/icons/corner-up-right.svg"
    cpu: str = ":/feather/icons/cpu.svg"
    credit_card: str = ":/feather/icons/credit-card.svg"
    crop: str = ":/feather/icons/crop.svg"
    crosshair: str = ":/feather/icons/crosshair.svg"
    database: str = ":/feather/icons/database.svg"
    delete: str = ":/feather/icons/delete.svg"
    disc: str = ":/feather/icons/disc.svg"
    divide: str = ":/feather/icons/divide.svg"
    divide_circle: str = ":/feather/icons/divide-circle.svg"
    divide_square: str = ":/feather/icons/divide-square.svg"
    dollar_sign: str = ":/feather/icons/dollar-sign.svg"
    download: str = ":/feather/icons/download.svg"
    download_cloud: str = ":/feather/icons/download-cloud.svg"
    dribbble: str = ":/feather/icons/dribbble.svg"
    droplet: str = ":/feather/icons/droplet.svg"
    edit: str = ":/feather/icons/edit.svg"
    edit_2: str = ":/feather/icons/edit-2.svg"
    edit_3: str = ":/feather/icons/edit-3.svg"
    external_link: str = ":/feather/icons/external-link.svg"
    eye: str = ":/feather/icons/eye.svg"
    eye_off: str = ":/feather/icons/eye-off.svg"
    facebook: str = ":/feather/icons/facebook.svg"
    fast_forward: str = ":/feather/icons/fast-forward.svg"
    feather: str = ":/feather/icons/feather.svg"
    figma: str = ":/feather/icons/figma.svg"
    file: str = ":/feather/icons/file.svg"
    file_minus: str = ":/feather/icons/file-minus.svg"
    file_plus: str = ":/feather/icons/file-plus.svg"
    file_text: str = ":/feather/icons/file-text.svg"
    film: str = ":/feather/icons/film.svg"
    filter: str = ":/feather/icons/filter.svg"
    flag: str = ":/feather/icons/flag.svg"
    folder: str = ":/feather/icons/folder.svg"
    folder_minus: str = ":/feather/icons/folder-minus.svg"
    folder_plus: str = ":/feather/icons/folder-plus.svg"
    framer: str = ":/feather/icons/framer.svg"
    frown: str = ":/feather/icons/frown.svg"
    gift: str = ":/feather/icons/gift.svg"
    git_branch: str = ":/feather/icons/git-branch.svg"
    git_commit: str = ":/feather/icons/git-commit.svg"
    git_merge: str = ":/feather/icons/git-merge.svg"
    git_pull_request: str = ":/feather/icons/git-pull-request.svg"
    github: str = ":/feather/icons/github.svg"
    gitlab: str = ":/feather/icons/gitlab.svg"
    globe: str = ":/feather/icons/globe.svg"
    grid: str = ":/feather/icons/grid.svg"
    hard_drive: str = ":/feather/icons/hard-drive.svg"
    hash: str = ":/feather/icons/hash.svg"
    headphones: str = ":/feather/icons/headphones.svg"
    heart: str = ":/feather/icons/heart.svg"
    help_circle: str = ":/feather/icons/help-circle.svg"
    hexagon: str = ":/feather/icons/hexagon.svg"
    home: str = ":/feather/icons/home.svg"
    image: str = ":/feather/icons/image.svg"
    inbox: str = ":/feather/icons/inbox.svg"
    info: str = ":/feather/icons/info.svg"
    instagram: str = ":/feather/icons/instagram.svg"
    italic: str = ":/feather/icons/italic.svg"
    key: str = ":/feather/icons/key.svg"
    layers: str = ":/feather/icons/layers.svg"
    layout: str = ":/feather/icons/layout.svg"
    life_buoy: str = ":/feather/icons/life-buoy.svg"
    link: str = ":/feather/icons/link.svg"
    link_2: str = ":/feather/icons/link-2.svg"
    linkedin: str = ":/feather/icons/linkedin.svg"
    list: str = ":/feather/icons/list.svg"
    loader: str = ":/feather/icons/loader.svg"
    lock: str = ":/feather/icons/lock.svg"
    log_in: str = ":/feather/icons/log-in.svg"
    log_out: str = ":/feather/icons/log-out.svg"
    mail: str = ":/feather/icons/mail.svg"
    map: str = ":/feather/icons/map.svg"
    map_pin: str = ":/feather/icons/map-pin.svg"
    maximize: str = ":/feather/icons/maximize.svg"
    maximize_2: str = ":/feather/icons/maximize-2.svg"
    meh: str = ":/feather/icons/meh.svg"
    menu: str = ":/feather/icons/menu.svg"
    message_circle: str = ":/feather/icons/message-circle.svg"
    message_square: str = ":/feather/icons/message-square.svg"
    mic: str = ":/feather/icons/mic.svg"
    mic_off: str = ":/feather/icons/mic-off.svg"
    minimize: str = ":/feather/icons/minimize.svg"
    minimize_2: str = ":/feather/icons/minimize-2.svg"
    minus: str = ":/feather/icons/minus.svg"
    minus_circle: str = ":/feather/icons/minus-circle.svg"
    minus_square: str = ":/feather/icons/minus-square.svg"
    monitor: str = ":/feather/icons/monitor.svg"
    moon: str = ":/feather/icons/moon.svg"
    more_horizontal: str = ":/feather/icons/more-horizontal.svg"
    more_vertical: str = ":/feather/icons/more-vertical.svg"
    mouse_pointer: str = ":/feather/icons/mouse-pointer.svg"
    move: str = ":/feather/icons/move.svg"
    music: str = ":/feather/icons/music.svg"
    navigation: str = ":/feather/icons/navigation.svg"
    navigation_2: str = ":/feather/icons/navigation-2.svg"
    octagon: str = ":/feather/icons/octagon.svg"
    package: str = ":/feather/icons/package.svg"
    paperclip: str = ":/feather/icons/paperclip.svg"
    pause: str = ":/feather/icons/pause.svg"
    pause_circle: str = ":/feather/icons/pause-circle.svg"
    pen_tool: str = ":/feather/icons/pen-tool.svg"
    percent: str = ":/feather/icons/percent.svg"
    phone: str = ":/feather/icons/phone.svg"
    phone_call: str = ":/feather/icons/phone-call.svg"
    phone_forwarded: str = ":/feather/icons/phone-forwarded.svg"
    phone_incoming: str = ":/feather/icons/phone-incoming.svg"
    phone_missed: str = ":/feather/icons/phone-missed.svg"
    phone_off: str = ":/feather/icons/phone-off.svg"
    phone_outgoing: str = ":/feather/icons/phone-outgoing.svg"
    pie_chart: str = ":/feather/icons/pie-chart.svg"
    play: str = ":/feather/icons/play.svg"
    play_circle: str = ":/feather/icons/play-circle.svg"
    plus: str = ":/feather/icons/plus.svg"
    plus_circle: str = ":/feather/icons/plus-circle.svg"
    plus_square: str = ":/feather/icons/plus-square.svg"
    pocket: str = ":/feather/icons/pocket.svg"
    power: str = ":/feather/icons/power.svg"
    printer: str = ":/feather/icons/printer.svg"
    radio: str = ":/feather/icons/radio.svg"
    refresh_ccw: str = ":/feather/icons/refresh-ccw.svg"
    refresh_cw: str = ":/feather/icons/refresh-cw.svg"
    repeat: str = ":/feather/icons/repeat.svg"
    rewind: str = ":/feather/icons/rewind.svg"
    rotate_ccw: str = ":/feather/icons/rotate-ccw.svg"
    rotate_cw: str = ":/feather/icons/rotate-cw.svg"
    rss: str = ":/feather/icons/rss.svg"
    save: str = ":/feather/icons/save.svg"
    scissors: str = ":/feather/icons/scissors.svg"
    search: str = ":/feather/icons/search.svg"
    send: str = ":/feather/icons/send.svg"
    server: str = ":/feather/icons/server.svg"
    settings: str = ":/feather/icons/settings.svg"
    share: str = ":/feather/icons/share.svg"
    share_2: str = ":/feather/icons/share-2.svg"
    shield: str = ":/feather/icons/shield.svg"
    shield_off: str = ":/feather/icons/shield-off.svg"
    shopping_bag: str = ":/feather/icons/shopping-bag.svg"
    shopping_cart: str = ":/feather/icons/shopping-cart.svg"
    shuffle: str = ":/feather/icons/shuffle.svg"
    sidebar: str = ":/feather/icons/sidebar.svg"
    skip_back: str = ":/feather/icons/skip-back.svg"
    skip_forward: str = ":/feather/icons/skip-forward.svg"
    slack: str = ":/feather/icons/slack.svg"
    slash: str = ":/feather/icons/slash.svg"
    sliders: str = ":/feather/icons/sliders.svg"
    smartphone: str = ":/feather/icons/smartphone.svg"
    smile: str = ":/feather/icons/smile.svg"
    speaker: str = ":/feather/icons/speaker.svg"
    square: str = ":/feather/icons/square.svg"
    star: str = ":/feather/icons/star.svg"
    stop_circle: str = ":/feather/icons/stop-circle.svg"
    sun: str = ":/feather/icons/sun.svg"
    sunrise: str = ":/feather/icons/sunrise.svg"
    sunset: str = ":/feather/icons/sunset.svg"
    table: str = ":/feather/icons/table.svg"
    tablet: str = ":/feather/icons/tablet.svg"
    tag: str = ":/feather/icons/tag.svg"
    target: str = ":/feather/icons/target.svg"
    terminal: str = ":/feather/icons/terminal.svg"
    thermometer: str = ":/feather/icons/thermometer.svg"
    thumbs_down: str = ":/feather/icons/thumbs-down.svg"
    thumbs_up: str = ":/feather/icons/thumbs-up.svg"
    toggle_left: str = ":/feather/icons/toggle-left.svg"
    toggle_right: str = ":/feather/icons/toggle-right.svg"
    tool: str = ":/feather/icons/tool.svg"
    trash: str = ":/feather/icons/trash.svg"
    trash_2: str = ":/feather/icons/trash-2.svg"
    trello: str = ":/feather/icons/trello.svg"
    trending_down: str = ":/feather/icons/trending-down.svg"
    trending_up: str = ":/feather/icons/trending-up.svg"
    triangle: str = ":/feather/icons/triangle.svg"
    truck: str = ":/feather/icons/truck.svg"
    tv: str = ":/feather/icons/tv.svg"
    twitch: str = ":/feather/icons/twitch.svg"
    twitter: str = ":/feather/icons/twitter.svg"
    type: str = ":/feather/icons/type.svg"
    umbrella: str = ":/feather/icons/umbrella.svg"
    underline: str = ":/feather/icons/underline.svg"
    unlock: str = ":/feather/icons/unlock.svg"
    upload: str = ":/feather/icons/upload.svg"
    upload_cloud: str = ":/feather/icons/upload-cloud.svg"
    user: str = ":/feather/icons/user.svg"
    user_check: str = ":/feather/icons/user-check.svg"
    user_minus: str = ":/feather/icons/user-minus.svg"
    user_plus: str = ":/feather/icons/user-plus.svg"
    user_x: str = ":/feather/icons/user-x.svg"
    users: str = ":/feather/icons/users.svg"
    video: str = ":/feather/icons/video.svg"
    video_off: str = ":/feather/icons/video-off.svg"
    voicemail: str = ":/feather/icons/voicemail.svg"
    volume: str = ":/feather/icons/volume.svg"
    volume_1: str = ":/feather/icons/volume-1.svg"
    volume_2: str = ":/feather/icons/volume-2.svg"
    volume_x: str = ":/feather/icons/volume-x.svg"
    watch: str = ":/feather/icons/watch.svg"
    wifi: str = ":/feather/icons/wifi.svg"
    wifi_off: str = ":/feather/icons/wifi-off.svg"
    wind: str = ":/feather/icons/wind.svg"
    x: str = ":/feather/icons/x.svg"
    x_circle: str = ":/feather/icons/x-circle.svg"
    x_octagon: str = ":/feather/icons/x-octagon.svg"
    x_square: str = ":/feather/icons/x-square.svg"
    youtube: str = ":/feather/icons/youtube.svg"
    zap: str = ":/feather/icons/zap.svg"
    zap_off: str = ":/feather/icons/zap-off.svg"
    zoom_in: str = ":/feather/icons/zoom-in.svg"
    zoom_out: str = ":/feather/icons/zoom-out.svg"
